@@ -113,7 +113,7 @@ module Raven
 
           next unless key.start_with?('HTTP_') || %w(CONTENT_TYPE CONTENT_LENGTH).include?(key)
           # Rack stores headers as HTTP_WHAT_EVER, we need What-Ever
-          key = key.gsub("HTTP_", "")
+          key = key.sub(/^HTTP_/, "")
           key = key.split('_').map(&:capitalize).join('-')
           memo[key] = value
         rescue StandardError => e
