@@ -409,6 +409,20 @@ RSpec.describe Raven::Event do
         expect(json["extra"]["circular"]["ary2"]).to eq("(...)")
       end
     end
+
+    context "with sensitive data" do
+      subject do
+        Raven::Event.new(:extra => {
+                           'password' => 'secretpassword'
+                         })
+      end
+
+      it "should sanitize password" do
+        json = subject.to_json_compatible
+
+        expect(json["extra"]["password"]).to eq(Raven::Processor::SanitizeData::STRING_MASK)
+      end
+    end
   end
 
   describe '.capture_message' do
@@ -461,8 +475,9 @@ RSpec.describe Raven::Event do
         expect(Raven::Event.capture_exception(exception)).to be_a(Raven::Event)
       end
 
-      it "sets the message to the exception's message and type" do
-        expect(hash[:message]).to eq("Exception: #{message}")
+      it "sets the message to the exception's value and type" do
+        expect(hash[:exception][:values][0][:type]).to eq("Exception")
+        expect(hash[:exception][:values][0][:value]).to eq(message)
       end
 
       it 'has level ERROR' do
